@@ -83,7 +83,6 @@ GLOBAL(unsigned int maxusers, DEFAULT_MAX_USERS);
 GLOBAL0(unsigned int per_user_max);
 GLOBAL0(unsigned int per_anon_max);
 #endif
-GLOBAL0(int iptropy);
 GLOBAL(volatile int xferfd, -1);
 #ifndef NO_STANDALONE
 GLOBAL0(unsigned int maxip);
@@ -164,6 +163,8 @@ GLOBAL0(signed char be_customer_proof);
 #ifdef WITH_TLS
 GLOBAL0(signed char enforce_tls_auth);
 GLOBAL0(int data_protection_level); 
+GLOBAL(const char *tlsciphersuite, NULL);
+GLOBAL0(signed char ssl_disabled);
 #endif
 
 GLOBAL0(char *atomic_prefix);
